@@ -399,15 +399,6 @@ sub interval_tsrange {
 
 =head3 interval_datelist
 
-    INTERVAL FILLUP _DATELIST
-    EMPLOYEE_SPEC INTERVAL FILLUP _DATELIST
-    INTERVAL FILLUP DRY_RUN _DATELIST
-    EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATELIST
-    INTERVAL FILLUP _MONTH _DATELIST
-    EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _DATELIST
-    INTERVAL FILLUP DRY_RUN _MONTH _DATELIST
-    EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _MONTH _DATELIST
-
 =cut
 
 sub interval_datelist {
@@ -429,18 +420,17 @@ sub interval_datelist {
     my $dry_run = exists( $th->{'DRY_RUN'} ) ? 1 : 0;
     $log->debug( "dry_run: $dry_run" );
 
-    # if _MONTH given, use it; otherwise use $prompt_month
-    my $month = $prompt_month;
-    if ( $th->{_MONTH} ) {
-        $month = _month_alpha_to_numeric( $th->{_MONTH} );
-    }
+    # check datelist for sanity
+    my $regex = qr/^(\d{1,2},|\d{1,2}-\d{1,2},)*(\d{1,2}|\d{1,2}-\d{1,2})$/;
+    return $CELL->status_err( "Invalid datelist" ) unless $th->{"_REST"} =~ $regex;
 
-    # convert _DATELIST token into reference to array of dates
-    my $dl = datelist_from_token( $month,  $th->{_DATELIST} );
+    # convert datelist into reference to array of dates
+    my $dl = datelist_from_token( $prompt_month,  $th->{_REST} );
     $log->debug( "datelist: " . Dumper( $dl ) );
     
     return _fillup(
         eid => $emp->eid,
+        code => $th->{_TERM},
         date_list => $dl,
         dry_run => $dry_run,
         clobber => 1,
@@ -763,6 +753,7 @@ EOS
 sub _fillup {
     my ( %ARGS ) = validate( @_, {
         eid => { type => SCALAR },
+        code => { type => SCALAR, optional => 1 },
         date_list => { type => ARRAYREF, optional => 1 },
         tsrange => { type => SCALAR, optional => 1 },
         dry_run => { type => SCALAR },
@@ -774,10 +765,19 @@ sub _fillup {
     my $status = send_req( 'POST', "interval/fillup", $request_body );
     return $status unless $status->ok;
 
-    my $count = $status->{'count'} ? $status->{'count'} : 0;
-    my $pl = "$count intervals added";
+    my ( $pl, $count );
+    if ( $status->code eq 'DISPATCH_FILLUP_INTERVALS_CREATED' ) {
+        my $tmp = $status->payload->{'success'}->{'count'};
+        $pl .= "$tmp intervals successfully inserted\n";
+        $tmp = $status->payload->{'failure'}->{'count'};
+        $pl .= "$tmp intervals not inserted due to conflicts\n";
+        if ( exists( $status->payload->{'clobbered'} ) ) {
+            $tmp = $status->payload->{'clobbered'}->{'count'};
+            $pl .= "$tmp existing intervals clobbered\n";
+        }
+    }
+    $count = $status->{'count'};
     return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $pl );
 }
 
-
 1;
